@@ -487,13 +487,23 @@ class haproxy_manager {
                 JOIN whp.domains d ON s.primary_domain_id = d.id
                 LEFT JOIN whp.site_domains sd ON s.id = sd.site_id AND sd.is_primary = 1
                 JOIN whp.container_types ct ON s.container_type_id = ct.id
-                WHERE sc.site_id = ? AND sc.status = 'running'
+                WHERE sc.site_id = ? AND sc.status = 'active'
             ");
             $stmt->execute([$site_id]);
             $containers = $stmt->fetchAll();
             
             // Configure each FQDN
             $results = [];
+            
+            // Check if we have containers
+            if (empty($containers)) {
+                error_log("HAProxy Manager: No active containers found for site_id $site_id");
+                return [
+                    'success' => false,
+                    'error' => 'No active containers found for site. Containers must be running before configuring HAProxy.'
+                ];
+            }
+            
             foreach ($site_domains as $site_domain) {
                 $fqdn = $site_domain['fqdn'] ?: $site_domain['domain_name']; // Use FQDN if available, fallback to domain_name
                 $servers = [];
